@@ -162,7 +162,7 @@ def finalise_lizardplot(plot, source_text, fontsize=12, pdf=False, output_name="
     # Get the directory of the current script
     current_directory = os.path.dirname(os.path.abspath(__file__))
     # Construct the path to the image
-    image_path = os.path.join(current_directory, 'logo', 'BioLizardLogo.png')
+    image_path = os.path.join(current_directory, 'logo', 'BiolizardLogo.png')
     # Read the image
     img = plt.imread(image_path)
 
